Zuora Connector Studio Demo
==============================

Mule Studio demo for Zuora subscribe operation

How to Run Demo
---------------

1. Import the project folder in Studio
2. Specify your Zuora credentials in /src/main/app/mule-app.properties
3. Run the project in Studio.
4. Type localhost:8081 in your browser to access the selection menu of the demo

About the Demo
--------------

There is a config file named: "mule-app.properties" where some configurable properties have to be provided:
* config.username - user name within Zuora system
* config.password - password within Zuora system
* config.endpoint - the endpoint called by the Zuora Soap operations
* config.restEndpoint - the endpoint called by the Zuora Rest operations
* config.wsdlLocation - the location of the Zuora WSDL
 
The project contains 18 simple flows that show how to successfully create a subscription and modify different components of that subscription. It must be noted that the 
Subscribe operation can combine all the operations from this demo into a single unit, but to make the process more clear, the necessary operations to create a subscription
are split. This Demo is split into 4 sections:


The first section is called "Create Subscription" and contains 8 flows. The goal of these flows is to create a subscription:

1.zuora-subscribe-operations-createAccount-demoFlow: Choose 'Create Account' in the selection menu.
This flow creates an account. For input, only the name must be provided. The demo uses some hard coded values for some fields like the Batch in which
the account is created, or the currency that the account will use. The account will be created in 'Draft' state.

2.zuora-subscribe-operations-createContact-demoFlow: Choose 'Create Contact' in the selection menu.
This flow creates a contact. For input, personal information like the first and last name or country need to be added. The Contact needs an existing Account Id.
The demo auto-completes this field with the id resulted from the creation of the Account in flow 1.

3.zuora-subscribe-operations-createPayment-demoFlow: Choose 'Create Payment' in the selection menu.
This flow creates a payment method for the subscription. For input, credit card information is required. The demo uses a Visa as a credit card type.
The demo auto-completes the Account Id with the id resulted from the creation of the Account in flow 1.

4.zuora-subscribe-operations-createProduct-demoFlow: Choose 'Create Product' in the selection menu.
This flow creates a product that has a name, start and end date. The date must have the format YYYY-MM-DD.

5.zuora-subscribe-operations-createProductRate-demoFlow: Choose 'Create Product Rate' in the selection menu.
This flow creates a product rate, that is an option which belongs to a product. Like a product, it has a name, start and end date.
The date must have the format YYYY-MM-DD. The demo auto-completes the Product Id with the id resulted from the creation of the Product in flow 4.

6.zuora-subscribe-operations-createProductRateCharge-demoFlow: Choose 'Create Product Rate Charge' in the selection menu.
This flow creates a payment strategy for a product rate.
The demo auto-completes the Product Rate Plan Id with the id resulted from the creation of the Product Rate Plan in flow 5. As it can be seen when analysing the
flow in studio, the used currency is USD with a price of 12 units.

7.zuora-subscribe-operations-updateAccount-demoFlow: Choose 'Update Account' in the selection menu.
This flow updates an account to an active state. In order for an account to be in Active State, it needs to have contact information assigned to it
for billing. The demo auto-completes the Account Id with the id resulted from the creation of the Account in flow 1. It also auto-completes
BillTo and SoldTo fields with the id resulted from the creation of the Contact in flow 2.

8.zuora-subscribe-operations-subscribe-demoFlow: Choose 'Subscribe' in the selection menu.
This flow creates a new subscription. The subscription needs an Account id, Payment Id, Contact Id and a Product Rate Plan Id. These are auto-completed
using the results from the previous flows. The subscription also needs a ContractAcceptanceDate and ContractEffectiveDate with the YYYY-MM-DD format. The
ContractAcceptanceDate represents the date when the customer accepts the contract and the ContractEffectiveDate represents the date when the contract takes
effect.


The second section is called Renew/Cancel Subscription and contains 2 flows that can renew or cancel an existing subscription:

1.zuora-renew-subscription-demoFlow: Choose 'Renew Subscription' in the selection menu.
This flow renews an existing subscription. If a subscription was created using the 'Create Subscription' section in the same session, then the Subscription Id field
will be auto-completed by the id of that subscription. The 'ServiceActivationDate' represents the date that the subscription starts, and the ContractEffectiveDate 
represents the date when the contract that governs the subscription takes effect.

2.zuora-cancel-subscription-demoFlow: Choose 'Cancel Subscription' in the selection menu.
This flow cancels an existing subscription. If a subscription was created using the 'Create Subscription' section in the same session, then the Subscription Id field
will be auto-completed by the id of that subscription. The 'ContractEffectiveDate' represents the date the contract expires and the 'EffectiveDate' date field
represents the date the subscription expires. After expiration, the value of the EffectiveDate is overwritten by the value of 'ContractEffectiveDate'.


The third section is called 'Modify Terms and Conditions' and contains a flow that allows 
you to extend or shorten the initial term or renewal term of the subscription:

1.zuora-change-term-of-service-demoFlow: Choose 'Change Terms and Conditions' in the selection menu.
This flow modifies the term related details of the subscription. If a subscription was created using the 'Create Subscription' section in the same session, then the Subscription Id field
will be auto-completed by the id of that subscription. The 'Term Start Date' field dictates when the term should start affecting the subscription.
The 'RenewalTermPeriodType' can have values as 'Day' or 'Week' for example. The 'RenewalTerm' field dictates how many days, weeks, etc(depends on the
value of 'RenewalTermPeriodType') the term will take action. The 'ContractEffectiveDate' dictates when the new contract changes will take action.


The fourth section is called 'Modify Subscription Products' and contains 7 flows that can add, update or delete products from a subscription:

1.zuora-amend-createNewProduct-demoFlow: Choose 'Create New Product' in the selection menu.
This flow creates a product that has a name, start and end date. The date must have the format YYYY-MM-DD. This Product will be added to an existing subscription.

2:zuora-amend-createNewProductRate-demoFlow: Choose 'Create New Product Rate' in the selection menu.
This flow creates a product rate, that is an option which belongs to a product. Like a product, it has a name, start and end date.
The date must have the format YYYY-MM-DD. The demo auto-completes the Product Id with the id resulted from the creation of the Product in flow 1.

3:zuora-amend-createNewProductRateCharge-demoFlow: Choose 'Create New Product Rate Charge' in the selection menu.
This flow creates a payment strategy for a product rate.
The demo auto-completes the Product Rate Plan Id with the id resulted from the creation of the Product Rate Plan in flow 2. As it can be seen when analysing the
flow in studio, the used currency is USD with a price of 12 units.

4:zuora-amend-addProducts-demoFlow": Choose Add Product For Subscription in the selection menu.
This flow adds a new product to an existing subscription. The demo auto-completes the Product Rate Plan Id with the id
 resulted from the creation of the Product Rate Plan in flow 2. If a subscription was created using the 'Create Subscription' section in the same session, then the Subscription Id field
will be auto-completed by the id of that subscription. The Service Activation Date represents the date the new product will be added to the subscription.
The 'Customer Acceptance Date' field represents the date when the customer accepts the contract. The 'Contract Effective Date' field represents the date
the contract starts.

5:zuora-amend-queryRateId-productsFlow Choose 'Query Rate Id' in the selection menu.
This flow queries the the Rate Id of a Product Rate  that was added to a subscription. When a product with a product rate is added to a subscription, a 
corresponding Rate object is created. To alter the product instance linked to the subscription, the id of the corresponding rate is required.
If the Product Rate was created in this session using flow 2, the query will be auto filled. If not, the query must have the form: "Select Id from RatePlan where ProductRatePlanId= ''",
and include the ProductRatePlanId that was used for the subscription.

6:zuora-amend-updateProducts-demoFlow: Choose Amend Update Product for Subscription.
This flow updates the charge quantity details of a subscription product to 7. If a subscription was created using the 'Create Subscription' section in the same session, then the Subscription Id field
will be auto-completed by the id of that subscription. For 'ProductRatePlanId', it needs the id field of a Rate object. The id can be retrieved using flow 
5. It also needs the id of the charge plan for the given product. All these fields are auto-completed if all the previous section flows are successfully run.
The Service Activation Date represents the date the new product will be added to the subscription.
The 'Customer Acceptance Date' field represents the date when the customer accepts the contract. The 'Contract Effective Date' field represents the date the contract starts.

7:zuora-amend-deleteProducts-demoFlow: Choose Amend Delete Product for Subscription.
This flow deletes a product from a subscription. If a subscription was created using the 'Create Subscription' section in the same session, then the Subscription Id field
will be auto-completed by the id of that subscription. For 'ProductRatePlanId', it needs the id field of a Rate object. The id can be retrieved using flow 
5. All these fields are auto-completed if all the previous section flows are successfully run.
The Service Activation Date represents the date the new product will be added to the subscription.
The 'Customer Acceptance Date' field represents the date when the customer accepts the contract. The 'Contract Effective Date' field represents the date the contract starts.



